@@ -11,11 +11,11 @@ from itertools import repeat
 import tensorflow as tf
 from tensorflow import keras
 from keras import Input
-from keras.applications import VGG19
+from tensorflow.keras.applications import VGG19
 from keras.callbacks import TensorBoard ,ModelCheckpoint
 from keras.layers import BatchNormalization, Activation, LeakyReLU, Add, Dense, Conv2D, UpSampling2D
 from keras.models import Model,load_model
-from keras.optimizers import Adam
+from tensorflow.keras.optimizers import Adam
 from keras.utils.vis_utils import plot_model
 
 
@@ -33,10 +33,10 @@ warnings.filterwarnings("ignore")
 
 
 # use seed for reproducible results
-SEED = 42
-tf.random.set_seed(SEED)
-np.random.seed(SEED)
-random.seed(SEED)
+#SEED = 42
+#tf.random.set_seed(SEED)
+#np.random.seed(SEED)
+#random.seed(SEED)
 
 
 
@@ -517,16 +517,18 @@ def save_images_test(original_image , sr_image, saved_path):
 
 	
 	
-def SRGAN_predict(lr_image_path, model_path): 
-  img =lr_image_path  
-  lr_images = sample_images_test(img) 
-  # normalize the images 
-  lr_images = lr_images / 127.5 - 1. 
-  model=load_model(model_path) 
-  generated_images = model.predict_on_batch(lr_images) 
-  lr_images2 = lr_images.reshape((64,64,3)) 
-  generated_images2= generated_images.reshape((256,256,3)) 
-  return lr_images2,generated_images2
+def SRGAN_predict(lr_image_path, model_path ,outputPath=None): 
+	img =lr_image_path  
+	lr_images = sample_images_test(img) 
+	# normalize the images 
+	lr_images = lr_images / 127.5 - 1.0 
+	model=load_model(model_path) 
+	generated_images = model.predict_on_batch(lr_images) 
+	lr_images2 = lr_images.reshape((64,64,3)) 
+	generated_images2= generated_images.reshape((256,256,3))
+	if outputPath!=None:
+		save_images_test(lr_images2 , generated_images2, outputPath)
+	return lr_images2,generated_images2
   
   
 
